@@ -1,6 +1,8 @@
 // Set source-map.js sourceMap to terser.js MOZ_SourceMap
 MOZ_SourceMap = sourceMap;
 
+var global = global || {};
+
 function comments(option) {
   if (Object.prototype.toString.call(option) === '[object Array]') {
     return new RegExp(option[0], option[1]);
@@ -47,7 +49,7 @@ function terser_wrapper(options) {
   inputs[inputFilename] = source;
 
   try {
-    return Terser.minifySync(inputs, options, null);
+    return Terser.minify_sync(inputs, options, null);
   } catch (error) {
     const { message, filename, line, col, pos } = error;
     return {error: {message: message, filename: filename, line: line, col: col, pos: pos}}
